Index: include/gpu/GrDistanceFieldTextContext.h |
diff --git a/include/gpu/GrBitmapTextContext.h b/include/gpu/GrDistanceFieldTextContext.h |
similarity index 63% |
copy from include/gpu/GrBitmapTextContext.h |
copy to include/gpu/GrDistanceFieldTextContext.h |
index e0900ecd7d625629418dd26e29a40d6617070bee..217faf3cb0213eaed917a5c5a56bef9b02800af6 100755 |
--- a/include/gpu/GrBitmapTextContext.h |
+++ b/include/gpu/GrDistanceFieldTextContext.h |
@@ -5,27 +5,27 @@ |
* found in the LICENSE file. |
*/ |
-#ifndef GrBitmapTextContext_DEFINED |
-#define GrBitmapTextContext_DEFINED |
+#ifndef GrDistanceFieldTextContext_DEFINED |
+#define GrDistanceFieldTextContext_DEFINED |
#include "GrTextContext.h" |
class GrTextStrike; |
/* |
* This class implements GrTextContext using standard bitmap fonts |
*/ |
-class GrBitmapTextContext : public GrTextContext { |
+class GrDistanceFieldTextContext : public GrTextContext { |
public: |
- GrBitmapTextContext(GrContext*, const GrPaint&, SkColor); |
- virtual ~GrBitmapTextContext(); |
+ GrDistanceFieldTextContext(GrContext*, const GrPaint&, SkColor, SkScalar textRatio); |
+ virtual ~GrDistanceFieldTextContext(); |
virtual void drawPackedGlyph(GrGlyph::PackedID, GrFixed left, GrFixed top, |
- GrFontScaler*) SK_OVERRIDE; |
+ GrFontScaler*) SK_OVERRIDE; |
private: |
- GrContext::AutoMatrix fAutoMatrix; |
- GrTextStrike* fStrike; |
+ GrTextStrike* fStrike; |
+ SkScalar fTextRatio; |
void flushGlyphs(); // automatically called by destructor |
@@ -5,27 +5,27 @@ |
class GrTextStrike; |
/* |
- * This class implements GrTextContext using standard bitmap fonts |
+ * This class implements GrTextContext using distance field fonts |
*/ |